expSedRamp: exponentially ramped sedimentation rate model to convert time...

View source: R/expSedRamp.R

expSedRampR Documentation

exponentially ramped sedimentation rate model to convert time to stratigraphy

Description

Apply a exponentially increasing increasing sedimentation rate model to convert time to stratigraphy.

Usage

expSedRamp(data, sr_start, sr_end)

Arguments

data

Input data set should consist of a matrix with 2 columns with the first being time and the second being the proxy

sr_start

Initial sedimentation rate (in cm/kyr).

sr_end

Final sedimentation rate (in cm/kyr).

Value

Returns a list which contains 10 elements element 1: time series in the depth (m) domain element 2: sedimentation rate curve

Author(s)

Based on the sedRamp function of the 'astrochron' R package.

References

Routines for astrochronologic testing, astronomical time scale construction, and time series analysis <doi:10.1016/j.earscirev.2018.11.015>

Examples


data_1 <- astrochron::etp(
tmin = 0,
tmax = 4000,
dt = 1,
eWt = 1.5,
oWt = 0.75,
pWt = 1,
esinw = TRUE,
solution = NULL,
standardize = TRUE,
genplot = FALSE,
verbose = FALSE
)
data_ramped_ls <- expSedRamp(data_1, sr_start = 1, sr_end = 5)

WaverideR documentation built on April 6, 2026, 5:06 p.m.