| expSedRamp | R Documentation |
Apply a exponentially increasing increasing sedimentation rate model to convert time to stratigraphy.
expSedRamp(data, sr_start, sr_end)
data |
Input data set should consist of a matrix with 2 columns with the first being time and the second being the proxy |
sr_start |
Initial sedimentation rate (in cm/kyr). |
sr_end |
Final sedimentation rate (in cm/kyr). |
Returns a list which contains 10 elements element 1: time series in the depth (m) domain element 2: sedimentation rate curve
Based on the sedRamp function of the 'astrochron' R package.
Routines for astrochronologic testing, astronomical time scale construction, and time series analysis <doi:10.1016/j.earscirev.2018.11.015>
data_1 <- astrochron::etp(
tmin = 0,
tmax = 4000,
dt = 1,
eWt = 1.5,
oWt = 0.75,
pWt = 1,
esinw = TRUE,
solution = NULL,
standardize = TRUE,
genplot = FALSE,
verbose = FALSE
)
data_ramped_ls <- expSedRamp(data_1, sr_start = 1, sr_end = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.